@@ -548,11 +548,22 @@ iphb_t close_iphb_handle(Iphb_cb_data data)
 	if(TRUE == iphb_configured) {
 		iphb_configured = FALSE;
 		int iphb_fd = 0;
+		/*iphbt_t is nothing but a (void*) */
+		iphb_t return_val = 0 ;
+		
 
 		gconf_client_set_bool(gconf, RSS_SETTINGS_ALARM_ID, iphb_configured, NULL);
 		gconf_client_set_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, iphb_fd, NULL);
 
-		return(iphb_close(data.iphb_handle));
+		/*defense added to prevent double free of iphb_handle */
+		DMSG(" About to free iphb handler  %d\n", data.iphb_handle);
+		if (data.iphb_handle != NULL ) {
+			/* iphbh handle will be freed inside */
+			DMSG(" freeing iphb handler \n");
+			return_val = iphb_close(data.iphb_handle);
+			data.iphb_handle = NULL;
+		}
+       		return return_val;		
 	}
 	return NULL;
 }
